@@ -10,7 +10,7 @@ from .settings import wagtail_jotform_settings
 def do_after_publish_page(request, page):
     if isinstance(page, EmbeddedFormPage) and page.form:
         thank_you_url = page.full_url + page.specific.reverse_subpage(
-            "embeded_form_thank_you"
+            "embedded_form_thank_you"
         )
 
         params = (("apiKey", wagtail_jotform_settings.API_KEY),)
